==> phoenix-tool-0.1.11-20240514.020519-1-sources.jar: com/elitesland/cbpl/tool/tenant/TenantSpiUtil.java <==
package com.elitesland.cbpl.tool.tenant;

import cn.hutool.core.text.StrPool;
import cn.hutool.core.util.StrUtil;
import cn.hutool.extra.spring.SpringUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.NoSuchBeanDefinitionException;

/**
 * @author eric.hao
 * @since 2024/01/16
 */
@Slf4j
public class TenantSpiUtil {

    /**
     * 当前租户编码
     *
     * @return 租户编码
     */
    public static String currentTenantCode() {
        try {
            TenantClientSpi<?> tenantClient = SpringUtil.getBean(TenantClientSpi.class);
            return tenantClient.currentTenantCode();
        } catch (NoSuchBeanDefinitionException e) {
            return "";
        }
    }

    /**
     * 租户前缀 (tenantCode_)
     *
     * @return 前缀
     */
    public static String tenantPrefix() {
        return tenantPrefix(StrPool.C_UNDERLINE);
    }

    /**
     * 租户前缀 (tenantCode_)
     *
     * @return 前缀
     */
    public static String tenantPrefix(char prefix) {
        String tenantCode = currentTenantCode();
        return StrUtil.isBlank(tenantCode) ? "" : tenantCode + prefix;
    }

    /**
     * 所有租户下都执行以下方法
     *
     * @param executor 业务代码
     */
    public static void byTenants(Runnable executor) {
        try {
            TenantClientSpi<?> tenantClient = SpringUtil.getBean(TenantClientSpi.class);
            tenantClient.byTenants(executor);
        }
        // 未配置租户实现，直接执行
        catch (NoSuchBeanDefinitionException e) {
            logger.warn("[PHOENIX-TENANT] TenantClientSpi NoSuchBeanDefinition");
            executor.run();
        }
    }
}

==> phoenix-tool-0.1.12.11-20240730.033752-1-sources.jar: com/elitesland/cbpl/tool/tenant/TenantSpiUtil.java <==
package com.elitesland.cbpl.tool.tenant;

import cn.hutool.core.text.StrPool;
import cn.hutool.core.util.StrUtil;
import cn.hutool.extra.spring.SpringUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.NoSuchBeanDefinitionException;

import java.util.function.Supplier;

/**
 * @author eric.hao
 * @since 2024/01/16
 */
@Slf4j
public class TenantSpiUtil {

    /**
     * 当前租户编码
     *
     * @return 租户编码
     */
    public static String currentTenantCode() {
        try {
            TenantClientSpi<?> tenantClient = SpringUtil.getBean(TenantClientSpi.class);
            return tenantClient.currentTenantCode();
        } catch (NoSuchBeanDefinitionException e) {
            return "";
        }
    }

    /**
     * 租户前缀 (tenantCode_)
     *
     * @return 前缀
     */
    public static String tenantPrefix() {
        return tenantPrefix(StrPool.C_UNDERLINE);
    }

    /**
     * 租户前缀 (tenantCode_)
     *
     * @return 前缀
     */
    public static String tenantPrefix(char prefix) {
        String tenantCode = currentTenantCode();
        return StrUtil.isBlank(tenantCode) ? "" : tenantCode + prefix;
    }

    /**
     * 所有租户下都执行以下方法
     *
     * @param executor 业务代码
     */
    public static void byTenants(Runnable executor) {
        try {
            TenantClientSpi<?> tenantClient = SpringUtil.getBean(TenantClientSpi.class);
            tenantClient.byTenants(executor);
        }
        // 未配置租户实现，直接执行
        catch (NoSuchBeanDefinitionException e) {
            logger.warn("[PHOENIX-TENANT] TenantClientSpi NoSuchBeanDefinition");
            executor.run();
        }
    }

    /**
     * 直接使用指定的租户
     * <p>
     * 以Runnable函数式接口类型为参数，没有返回结果
     *
     * @param executor   业务侧执行方法
     * @param tenantCode 租户编码
     * @since 0.1.13-SNAPSHOT
     */
    public static void byTenantDirectly(Runnable executor, String tenantCode) {
        try {
            TenantClientSpi<?> tenantClient = SpringUtil.getBean(TenantClientSpi.class);
            tenantClient.byTenantDirectly(executor, tenantCode);
        }
        // 未配置租户实现，直接执行
        catch (NoSuchBeanDefinitionException e) {
            logger.warn("[PHOENIX-TENANT] TenantClientSpi NoSuchBeanDefinition");
            executor.run();
        }
    }

    /**
     * 直接使用指定的租户
     * <p>
     * 以Supplier函数式接口类型为参数，返回结果类型为E
     *
     * @param executor   业务操作
     * @param tenantCode 租户编码
     * @param <E>        数据类型
     * @return 数据
     * @since 0.1.13-SNAPSHOT
     */
    public static <E> E byTenantDirectly(Supplier<E> executor, String tenantCode) {
        try {
            TenantClientSpi<?> tenantClient = SpringUtil.getBean(TenantClientSpi.class);
            return tenantClient.byTenantDirectly(executor, tenantCode);
        }
        // 未配置租户实现，直接执行
        catch (NoSuchBeanDefinitionException e) {
            logger.warn("[PHOENIX-TENANT] TenantClientSpi NoSuchBeanDefinition");
            return executor.get();
        }
    }
}
